@@ -3,7 +3,7 @@
 // Bench script of Cache_Lite_Output
 // $Id$
 
-require_once 'Cache/Lite/Output.php';
+require_once __DIR__ . '/../Cache/Lite/Output.php';
 
 $options = array(
     'caching' => true,
@@ -21,4 +21,4 @@ if (!($cache->start('123'))) {
     $cache->end();
 }
 
-?>
\ No newline at end of file
+?>
